# Table of Contents

- [step-6-track-and-report](<./step-6-track-and-report.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Step 6: Track and Report](<./Step-6-Track-and-Report.md>)
  - [Create a Custom Dashboard for AI Governance](<./Step-6-Track-and-Report/Create-a-Custom-Dashboard-for-AI-Governance.md>)
  - [Use the AI Agent Hub Dashboard](<./Step-6-Track-and-Report/Use-the-AI-Agent-Hub-Dashboard.md>)
  - [Monitor KPIs for AI Agents on the Architecture Executive Dashboard](<./Step-6-Track-and-Report/Monitor-KPIs-for-AI-Agents-on-the-Architecture-Executive-Dashboard.md>)
